Struct border_core::Step
source · [−]pub struct Step<E: Env> {
pub act: E::Act,
pub obs: E::Obs,
pub reward: Vec<f32>,
pub is_done: Vec<i8>,
pub info: E::Info,
pub init_obs: E::Obs,
}Expand description
All information given at every step of agent-envieronment interaction.
Old versions of the library support veectorized environments, which requires
elements in Step to be able to handle multiple values.
This is why reward and is_done are vector.
Fields
act: E::ActAction.
obs: E::ObsObservation.
reward: Vec<f32>Reward.
is_done: Vec<i8>Flag denoting if episode is done.
info: E::InfoInformation defined by user.
init_obs: E::ObsInitial observation. If is_done[i] == 0, the corresponding element will not be used.